aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/usrp/usrp2/clock_control.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/usrp/usrp2/clock_control.hpp')
-rw-r--r--host/lib/usrp/usrp2/clock_control.hpp7
1 files changed, 3 insertions, 4 deletions
diff --git a/host/lib/usrp/usrp2/clock_control.hpp b/host/lib/usrp/usrp2/clock_control.hpp
index 4302941f0..b64a53196 100644
--- a/host/lib/usrp/usrp2/clock_control.hpp
+++ b/host/lib/usrp/usrp2/clock_control.hpp
@@ -18,8 +18,7 @@
#ifndef INCLUDED_CLOCK_CONTROL_HPP
#define INCLUDED_CLOCK_CONTROL_HPP
-class usrp2_impl; //dummy class
-
+#include "usrp2_iface.hpp"
#include <boost/shared_ptr.hpp>
#include <boost/utility.hpp>
@@ -29,10 +28,10 @@ public:
/*!
* Make a clock config for the ad9510 ic.
* \param impl a pointer to the usrp2 implementation object
* \return a new clock control object
*/
- static sptr make_ad9510(usrp2_impl *impl);
+ static sptr make_ad9510(usrp2_iface::sptr iface);
/*!
* Enable/disable the rx dboard clock.
@@ -29,10 +28,10 @@ public:
/*!
* Make a clock config for the ad9510 ic.
- * \param impl a pointer to the usrp2 implementation object
+ * \param _iface a pointer to the usrp2 interface object
* \return a new clock control object
*/